Installation — Flower 0.8.0 documentation

### Navigation

- next
- previous |
- Flower 0.8.0 documentation »

# Installation

Installing flower with pip is simple

    $ pip install flower

Or, with easy_install

    $ easy_install flower

## Usage

Launch the server and open http://localhost:5555:

    $ flower --port=5555

Or, launch from Celery:

    $ celery flower --address=127.0.0.1 --port=5555

Broker URL and other configuration options can be passed through the standard Celery options:

    $ celery flower --broker=amqp://guest:guest@localhost:5672//

### Navigation

- next
- previous |
- Flower 0.8.0 documentation »